@@ -4,13 +4,12 @@ from ddd_objects.infrastructure.ao import exception_class_dec
 from ddd_objects.infrastructure.repository_impl import error_factory
 from ddd_objects.domain.exception import return_codes
 from .do import (
+    ReleaseNodeInfoDO,
     ConditionDO,
     ConfigMapDO,
     ConfigMapUserSettingDO,
     DeploymentDO,
     IngressDO,
-    InstanceInfoDO,
-    InstanceTypeWithStatusDO,
     JobDO,
     JobSettingDO,
     NamespaceDO,
@@ -73,7 +72,7 @@ class K3SController:
             return [NodeInfoDO(**info) for info in infos]
 
     @exception_class_dec(max_try=1)
-    def delete_nodes(self, node_infos: List[Union[NodeInfoDO, NodeMetaDO]], timeout=60):
+    def delete_nodes(self, node_infos: List[ReleaseNodeInfoDO], timeout=60):
         data = [info.dict() for info in node_infos]
         data = json.dumps(data)
         response=requests.delete(f'{self.url}/nodes', headers=self.header, data=data, timeout=timeout)
@@ -90,27 +89,7 @@ class K3SController:
         return succeed
 
     @exception_class_dec(max_try=1)
-    def get_instance_info_by_node_meta(self, region_id: str, node_meta: NodeMetaDO, timeout=10):
-        data = json.dumps(node_meta.dict())
-        response=requests.get(f'{self.url}/instance/region_id/{region_id}/node_meta', 
-            headers=self.header, data=data, timeout=timeout)
-        info = json.loads(response.text)
-        self._check_error(response.status_code, info)
-        instance_info, instance_type_info = info
-        instance_info = InstanceInfoDO(**instance_info)
-        instance_type_info = InstanceTypeWithStatusDO(**instance_type_info)
-        return instance_info, instance_type_info
-
-    @exception_class_dec(max_try=1)
-    def get_existing_nodes(self, cluster_name: str, timeout=10):
-        response=requests.get(f'{self.url}/nodes/cluster_name/{cluster_name}', 
-            headers=self.header, timeout=timeout)
-        infos = json.loads(response.text)
-        self._check_error(response.status_code, infos)
-        return [NodeInfoDO(**info) for info in infos]
-
-    @exception_class_dec(max_try=1)
-    def get_existing_nodes_by_name(self, node_name:str, timeout=10):
+    def get_nodes_by_name(self, node_name:str, timeout=10):
         response=requests.get(f'{self.url}/nodes/node_name/{node_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
@@ -118,26 +97,24 @@ class K3SController:
         return [NodeInfoDO(**info) for info in infos]
 
     @exception_class_dec(max_try=1)
-    def get_node_metas(self, cluster_name: str, timeout=7):
-        response=requests.get(f'{self.url}/node_metas/cluster_name/{cluster_name}', 
+    def get_node_metas(self,  timeout=7):
+        response=requests.get(f'{self.url}/node_metas', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
         return [NodeMetaDO(**meta) for meta in infos]
 
     @exception_class_dec(max_try=1)
-    def add_node_label(self, node_infos: List[NodeInfoDO], key: str, value: str, timeout=10):
-        data = [info.dict() for info in node_infos]
-        data = json.dumps(data)
-        response=requests.post(f'{self.url}/label/key/{key}/value/{value}', 
-            headers=self.header, data=data, timeout=timeout)
+    def add_node_label(self, node_name: str, key: str, value: str, timeout=3):
+        response=requests.post(f'{self.url}/label/node_name/{node_name}/key/{key}/value/{value}', 
+            headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
         return infos
 
     @exception_class_dec(max_try=1)
-    def get_namespaces(self, cluster_name: str, timeout=10):
-        response=requests.get(f'{self.url}/namespaces/cluster_name/{cluster_name}', 
+    def get_namespaces(self,  timeout=10):
+        response=requests.get(f'{self.url}/namespaces', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
@@ -147,9 +124,9 @@ class K3SController:
             return [NamespaceDO(**namespace) for namespace in infos]
 
     @exception_class_dec(max_try=1)
-    def create_namespace(self, cluster_name: str, namespace_name: str, timeout=10):
+    def create_namespace(self,  namespace_name: str, timeout=10):
         response=requests.post(
-            f'{self.url}/namespace/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            f'{self.url}/namespace/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
@@ -158,23 +135,22 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def create_secrets(
         self, 
-        cluster_name: str, 
         secret_user_settings: List[SecretUserSettingDO],
         timeout=300
     ):
         data = [setting.to_json() for setting in secret_user_settings]
         data = json.dumps(data)
         response=requests.post(
-            f'{self.url}/secrets/cluster_name/{cluster_name}', 
+            f'{self.url}/secrets', 
             headers=self.header, data=data, timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
         return info
 
     @exception_class_dec(max_try=1)
-    def get_secrets(self, cluster_name: str, namespace_name: str, timeout=10):
+    def get_secrets(self, namespace_name: str, timeout=10):
         response=requests.get(
-            f'{self.url}/secrets/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            f'{self.url}/secrets/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
@@ -186,23 +162,22 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def create_config_maps(
         self, 
-        cluster_name: str, 
         config_map_user_settings: List[ConfigMapUserSettingDO],
         timeout=10
     ):
         data = [setting.to_json() for setting in config_map_user_settings]
         data = json.dumps(data)
         response=requests.post(
-            f'{self.url}/config_maps/cluster_name/{cluster_name}', 
+            f'{self.url}/config_maps', 
             headers=self.header, data=data, timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
         return info
 
     @exception_class_dec(max_try=1)
-    def get_config_maps(self, cluster_name:str, namespace_name:str, timeout=10):
+    def get_config_maps(self, namespace_name:str, timeout=10):
         response=requests.get(
-            f'{self.url}/config_maps/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            f'{self.url}/config_maps/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
@@ -212,33 +187,9 @@ class K3SController:
             return [ConfigMapDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
-    def create_resource_from_oss(self, cluster_name:str, target_paths:List[str], timeout=60):
-        resource_oss_setting = ResourceOSSSettingDO(
-            cluster_name=cluster_name, target_paths=target_paths)
-        data = json.dumps(resource_oss_setting.to_json())
-        response=requests.post(
-            f'{self.url}/resource/oss', 
-            headers=self.header, data=data, timeout=timeout)
-        info = json.loads(response.text)
-        self._check_error(response.status_code, info)
-        return info
-
-    @exception_class_dec(max_try=1)
-    def delete_resource_from_oss(self, cluster_name: str, target_paths: List[str], timeout=60):
-        resource_oss_setting = ResourceOSSSettingDO(
-            cluster_name=cluster_name, target_paths=target_paths)
-        data = json.dumps(resource_oss_setting.to_json())
-        response=requests.delete(
-            f'{self.url}/resource/oss', 
-            headers=self.header, data=data, timeout=timeout)
-        info = json.loads(response.text)
-        self._check_error(response.status_code, info)
-        return info
-
-    @exception_class_dec(max_try=1)
-    def get_deployments(self, cluster_name:str, namespace_name:str, timeout=10):
+    def get_deployments(self, namespace_name:str, timeout=10):
         response=requests.get(
-            f'{self.url}/deployments/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            f'{self.url}/deployments/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
@@ -248,9 +199,9 @@ class K3SController:
             return [DeploymentDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
-    def get_ingresses(self, cluster_name:str, namespace_name:str, timeout=30):
+    def get_ingresses(self, namespace_name:str, timeout=30):
         response=requests.get(
-            f'{self.url}/ingresses/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            f'{self.url}/ingresses/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
@@ -260,9 +211,9 @@ class K3SController:
             return [IngressDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
-    def get_pods(self, cluster_name:str, namespace_name:str, timeout=30):
+    def get_pods(self, namespace_name:str, timeout=30):
         response=requests.get(
-            f'{self.url}/pods/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            f'{self.url}/pods/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
@@ -272,9 +223,9 @@ class K3SController:
             return [PodDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
-    def delete_pod(self, cluster_name:str, namespace_name:str, pod_name:str, timeout=5):
+    def delete_pod(self, namespace_name:str, pod_name:str, timeout=5):
         response=requests.delete(
-            f'{self.url}/pod/cluster_name/{cluster_name}/namespace_name/{namespace_name}/pod_name/{pod_name}', 
+            f'{self.url}/pod/namespace_name/{namespace_name}/pod_name/{pod_name}', 
             headers=self.header, timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
@@ -291,9 +242,9 @@ class K3SController:
         return info
 
     @exception_class_dec(max_try=1)
-    def get_services(self, cluster_name:str, namespace_name:str, timeout=30):
+    def get_services(self, namespace_name:str, timeout=30):
         response=requests.get(
-            f'{self.url}/services/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            f'{self.url}/services/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
@@ -303,9 +254,9 @@ class K3SController:
             return [ServiceDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
-    def get_pod_containers(self, cluster_name:str, namespace_name:str, timeout=30):
+    def get_pod_containers(self, namespace_name:str, timeout=30):
         response=requests.get(
-            f'{self.url}/pod_containers/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            f'{self.url}/pod_containers/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
@@ -315,9 +266,9 @@ class K3SController:
             return [PodContainerDO(**s) for s in infos]
 
     @exception_class_dec(max_try=1)
-    def get_jobs(self, cluster_name:str, namespace_name:str, timeout=10):
+    def get_jobs(self, namespace_name:str, timeout=10):
         response=requests.get(
-            f'{self.url}/jobs/cluster_name/{cluster_name}/namespace_name/{namespace_name}', 
+            f'{self.url}/jobs/namespace_name/{namespace_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
@@ -327,10 +278,10 @@ class K3SController:
             return [JobDO(**s) for s in infos]
         
     @exception_class_dec(max_try=1)
-    def create_job(self, cluster_name:str, job_setting:JobSettingDO, timeout=10):
+    def create_job(self, job_setting:JobSettingDO, timeout=10):
         data = json.dumps(job_setting.dict())
         response=requests.post(
-            f'{self.url}/job/cluster_name/{cluster_name}', 
+            f'{self.url}/job', 
             headers=self.header, data=data, timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
@@ -342,13 +293,12 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def get_pod_log(
         self, 
-        cluster_name:str,
         pod_log_setting: PodLogSettingDO,
         timeout:int=10
     ):
         data = json.dumps(pod_log_setting.to_json())
         response=requests.get(
-            f'{self.url}/log/cluster_name/{cluster_name}', 
+            f'{self.url}/log', 
             headers=self.header, data=data,timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
@@ -357,13 +307,12 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def delete_job(
         self,
-        cluster_name:str,
         namespace_name:str,
         job_name:str,
         timeout:int=10
     ):
         response=requests.delete(
-            f'{self.url}/job/cluster_name/{cluster_name}/namespace_name/{namespace_name}/job_name/{job_name}', 
+            f'{self.url}/job/namespace_name/{namespace_name}/job_name/{job_name}', 
             headers=self.header, timeout=timeout)
         info = json.loads(response.text)
         self._check_error(response.status_code, info)
@@ -372,13 +321,12 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def create_storage_class(
         self,
-        cluster_name: str,
         storage_class: StorageClassDO,
         timeout: int = 3
     ):
         data = json.dumps(storage_class.dict())
         response = requests.post(
-            f'{self.url}/storage_class/cluster_name/{cluster_name}',
+            f'{self.url}/storage_class',
             headers=self.header, data=data, timeout=timeout
         )
         info = json.loads(response.text)
@@ -388,12 +336,11 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def delete_storage_class(
         self,
-        cluster_name: str,
         storage_class_name: str,
         timeout: int = 3
     ):
         response = requests.delete(
-            f'{self.url}/storage_class/cluster_name/{cluster_name}/storage_class_name/{storage_class_name}',
+            f'{self.url}/storage_class/storage_class_name/{storage_class_name}',
             headers=self.header, timeout=timeout
         )
         info = json.loads(response.text)
@@ -403,13 +350,12 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def create_persistent_volume(
         self,
-        cluster_name: str,
         persistent_volume: PersistentVolumeDO,
         timeout: int = 3
     ):
         data = json.dumps(persistent_volume.dict())
         response = requests.post(
-            f'{self.url}/persistent_volume/cluster_name/{cluster_name}',
+            f'{self.url}/persistent_volume',
             headers=self.header, data=data, timeout=timeout
         )
         info = json.loads(response.text)
@@ -419,12 +365,11 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def delete_persistent_volume(
         self,
-        cluster_name: str,
         persistent_volume_name: str,
         timeout: int = 3
     ):
         response = requests.delete(
-            f'{self.url}/persistent_volume/cluster_name/{cluster_name}/persistent_volume_name/{persistent_volume_name}',
+            f'{self.url}/persistent_volume/persistent_volume_name/{persistent_volume_name}',
             headers=self.header, timeout=timeout
         )
         info = json.loads(response.text)
@@ -434,13 +379,12 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def create_persistent_volume_claim(
         self,
-        cluster_name: str,
         persistent_volume_claim: PersistentVolumeClaimDO,
-        timeout: int = 3
+        timeout: int = 5
     ):
         data = json.dumps(persistent_volume_claim.dict())
         response = requests.post(
-            f'{self.url}/persistent_volume_claim/cluster_name/{cluster_name}',
+            f'{self.url}/persistent_volume_claim',
             headers=self.header, data=data, timeout=timeout
         )
         info = json.loads(response.text)
@@ -450,13 +394,12 @@ class K3SController:
     @exception_class_dec(max_try=1)
     def delete_persistent_volume_claim(
         self,
-        cluster_name: str,
         namespace_name: str,
         persistent_volume_claim_name: str,
-        timeout: int = 3
+        timeout: int = 5
     ):
         response = requests.delete(
-            f'{self.url}/persistent_volume_claim/cluster_name/{cluster_name}/namespace_name/{namespace_name}/persistent_volume_claim_name/{persistent_volume_claim_name}',
+            f'{self.url}/persistent_volume_claim/namespace_name/{namespace_name}/persistent_volume_claim_name/{persistent_volume_claim_name}',
             headers=self.header, timeout=timeout
         )
         info = json.loads(response.text)
@@ -484,6 +427,7 @@ class K3SController:
         if item is None:
             return None
         else:
+            print(item)
             return NodeCreationItemDO(**item)
 
     @exception_class_dec()
@@ -522,3 +466,10 @@ class K3SController:
         self._check_error(response.status_code, succeed)
         return succeed
 
+    @exception_class_dec()
+    def delete_namespace(self, namespace_name:str, timeout=10):
+        response=requests.delete(f'{self.url}/namespace/namespace_name/{namespace_name}', 
+            headers=self.header, timeout=timeout)
+        succeed = json.loads(response.text)
+        self._check_error(response.status_code, succeed)
+        return succeed
\ No newline at end of file
