@@ -31,6 +31,7 @@ class NodeUserSettingDO(BaseModel):
     inner_connection: bool=True
     amount: int=1
 
+
 class NodeInfoDO(BaseModel):
     node_name: str
     node_type: str
@@ -46,24 +47,24 @@ class NodeInfoDO(BaseModel):
     pay_type: str
     security_group_id: List[str]
     node_label: Union[str, Dict]
-    cpu_number: int
-    memory_size: float
-    gpu_type: str
-    gpu_number: int
-    instance_type_status: str
-    instance_type_status_category: str
+    cpu_number: Optional[int]
+    memory_size: Optional[float]
+    gpu_type: Optional[str]
+    gpu_number: Optional[int]
+    instance_type_status: Optional[str]
+    instance_type_status_category: Optional[str]
     instance_name: str
     instance_status: str
     instance_create_time: str
     os_name: str
     public_ip: List[str]
     private_ip: str
-    bandwidth_in: str
-    bandwidth_out: str
-    expired_time: str
-    auto_release_time: str
+    bandwidth_in: int
+    bandwidth_out: int
+    node_expired_time: Optional[str]
+    auto_release_time: Optional[str]
     key_name: str
-    run_time: Optional[str]=None
+    run_time: Optional[Union[int, datetime.timedelta]]=None
     k3s_version: Optional[str]=None
     _life_time: int=5
 
@@ -467,4 +468,9 @@ class PersistentVolumeClaimDO(BaseModel):
     access_modes: Optional[List[str]]=None
     storage_class_name: Optional[str]=None
     limits: Optional[Dict]=None
-    requests: Optional[Dict]=None
\ No newline at end of file
+    requests: Optional[Dict]=None
+
+class ReleaseNodeInfoDO(BaseModel):
+    node_name: str
+    region_id: str
+    instance_id: str
\ No newline at end of file
